@@ -22,7 +22,7 @@ use File::Basename ();
 use File::Path ();
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -117,10 +117,6 @@ BEGIN {
   unshift @INC, sub {
     my($self, $file) = @_;
 
-    # avoid deep recursion
-    state $first;
-    Mojo::Loader::load_class('main') unless $first++;
-  
     my $data = Mojo::Loader::data_section('main', "lib/$file");
     return unless defined $data;
     
@@ -239,7 +235,7 @@ sub create_cluster_ok
   my $has_clustericious_config = 0;
   
   my $caller = caller;
-  Mojo::Loader::load_class($caller);
+  Mojo::Loader::load_class($caller) if $caller ne 'main';
 
   local @INC = @INC;
   $self->extract_data_section(qr{^lib/}, $caller);
@@ -678,7 +674,7 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
